#!/bin/sh

function log_filter {
awk -v "from=$1" -v "to=$2" '
	/^--------------------/ {next}
	/^[ 	]*$/ {next}
	
	/^r[0-9][0-9]* \|/ {
		rev=$1
		sub("^r", "", rev)		
		if (rev > to)
			exit
		next
	}
	
	{
		if (rev >= from) {
			print "r" rev " " $0
		}
	}
' < svn-merge.svnlog
}


# read config and state files
. svn-merge.conf

if test -f svn-merge.last
then
	last=`cat svn-merge.last`
else
	last=1
fi

echo "Download the log from revision $last..."
svn -r $last:HEAD log $trunk > svn-merge.svnlog

# Determining head revision
head=`grep "^r[0-9][0-9]* |" svn-merge.svnlog | tail -n 1 | sed "s/|.*//;s/^r//"`
echo "Head revision in trunk is $head"

if test $last = $head
then
	echo "Nothing new to merge."
	exit
fi


for n in `seq $last $head`
do
	let m=$n+1
	echo "Merging r$n..."
	res=`svn -r $n:$m merge $trunk $local | grep "^C"`
	if ! test -z "$res"
	then
		echo "List of colliding files:"
		echo "$res"
		echo ""		
		echo "Stopping: detected collision. Please fix. Commit using svn-merge.log"
		echo "Merged: $last..$n"
		log_filter $last $n > svn-merge.log
		rm -f svn-merge.svnlog
		echo $m > svn-merge.last		
		exit
	fi
done

rm -f svn-merge.svnlog
echo $head > svn-merge.last

echo "Merged: $last..$head"
echo "Merged all new revisions. Commit using svn-merge.log"
log_filter $last $head > svn-merge.log
