/*
    libgpmi - General Package/Module Interface - bgproc package
    Copyright (C) 2006-2007 Tibor 'Igor2' Palinkas & glx 
  
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
  
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
  
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdlib.h>
#include "bgproc_os_dep.h"

int main()
{
	pipe_t pa[2], pb[2];
	int len;
	char s[16];

	if (bgproc_create_pipe(pa, BGPROC_PIPE_WRITE) != 0) {
		/* main->sub */
		printf("Pipe1 fails\n");
		return 1;
	}

	if (bgproc_create_pipe(pb, BGPROC_PIPE_READ) != 0) {
		/* sub->main */
		printf("Pipe2 fails\n");
		return 1;
	}

	if (bgproc_create_child("./sub", pa, pb)) {
		printf("CreateChildProcess failed\n");
		return 1;
	}

	printf("parent: writing\n");
	len = bgproc_write_to_pipe(pa[BGPROC_PIPE_WRITE], "1234\n5678\n", 10);
	printf("parent: reading (wrote %d bytes)\n", len);

	*s = '\0';
	len = bgproc_read_from_pipe(pb[BGPROC_PIPE_READ], s,
#ifdef WIN32
				8
#else
				6
#endif
				);

	if ((len > 0) && (len < sizeof(s)))
		s[len] = '\0';

	printf("parent: read: '%s'/%d\n", s, len);

	if (strncmp(s, "2345\n", 5) != 0)
		printf("FAIL: got bad string\n");

	*s = '\0';
	len = bgproc_read_from_pipe(pb[BGPROC_PIPE_READ], s, sizeof(s));

	if ((len > 0) && (len < sizeof(s)))
		s[len] = '\0';

	printf("parent: read: '%s'/%d\n", s, len);

	if (strncmp(s, "6789\n", 5) != 0)
		printf("FAIL: got bad string\n");

	printf("parent: quiting\n");
#ifdef WIN32
	TerminateProcess(_hProcess, 0);
	CloseHandle(_hProcess);
	CloseHandle(pa[BGPROC_PIPE_WRITE]);
	CloseHandle(pb[BGPROC_PIPE_READ]);
#endif
	return 0;
}
